#!/bin/bash
#
# VERSION=3
# CHANGES="use find to list files to delete"

# global variables #

PATH=${PATH}:/bin:/sbin:/usr/local/bin:/usr/local/sbin

if [ -x /usr/local/bin/beroconf ]; then
	BEROCONF=/usr/local/bin/beroconf
else
	BEROCONF=/usr/fallback/beroconf
fi

ADM_HOM=/home/admin

LOG_NAM=log-full.log
LOG_DIR=${ADM_HOM}/log
LOG_TMP=/tmp/${LOG_NAM}
LOG_SAV=${LOG_DIR}/${LOG_NAM}
LOG_MAX=6144
LOG_LST="tcpDump tcpDump.lo ISDNdebug-1 ISDNdebug-2 ISDNdebug-3 ISDNdebug-4 ISDNdebug-5 ISDNdebug-6 ISDNdebug-7 ISDNdebug-8 DebugFiles.tar.gz"
LOG_TAR="DebugFiles.tar.gz"

PREFIX="[permanentlog_check]"

# functions #

function check_and_delete {

	for i in $(echo ${LOG_LST}); do
		space_used=$(echo $(df ${ADM_HOM} | grep "/dev/mtdblock") | cut -d" " -f3)
		if [ "${space_used}" -gt "${LOG_MAX}" ]; then
			rm -f ${LOG_DIR}/${i}
		fi
		unset space_used
	done
}


function create_log_full {

	rm -f ${LOG_SAV}
	echo -n "${LOG_NAM} created on $(date):" > ${LOG_TMP}

	for i in $(find ${LOG_DIR} -type f); do
		if [ "${i}" = "${LOG_DIR}/${LOG_TAR}" ]; then
			echo "${PREFIX} ignoring ${i}"
		elif [ -f ${i} ]; then
			echo "${PREFIX} concatting ${i}"
			echo -e "\n\n${i}:" >> ${LOG_TMP}
			cat ${i} >> ${LOG_TMP}
		fi
	done

	mv ${LOG_TMP} ${LOG_SAV}
}

function delete_all {

	space_used=$(echo $(df ${ADM_HOM} | grep "/dev/mtdblock") | cut -d" " -f3)
	if [ "${space_used}" -gt "${LOG_MAX}" ]; then
		for i in $(find ${LOG_DIR} | grep -v "${LOG_NAM}"); do
			rm -rf ${i}
		done
	fi
	unset space_used
}


# main #

logmode=$(${BEROCONF} get root userapp-logmode | grep -v failed)

if [ "${logmode}" != "1" ]; then
	echo "Logfile mode disabled in root.db, leaving." >&2
	exit 1
fi

check_and_delete
create_log_full
delete_all
